( cd usr/lib64 ; rm -rf libwraster.so )
( cd usr/lib64 ; ln -sf libwraster.so.3.1.0 libwraster.so )
( cd usr/lib64 ; rm -rf libwraster.so.3 )
( cd usr/lib64 ; ln -sf libwraster.so.3.1.0 libwraster.so.3 )
